@@ -39,13 +39,11 @@
 #include <sys/param.h>
 #include <sys/wait.h>
 
-#include <paths.h>
 #include <ctype.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <syslog.h>
 #include <errno.h>
-#include <err.h>
 
 #include "usuals.h"
 
@@ -153,6 +151,10 @@ static int clam_scan_file(clctx_t* ctx, const char** virus);
  *  STARTUP ETC...
  */
 
+#ifndef HAVE___ARGV
+char** __argv;
+#endif
+
 int main(int argc, char* argv[])
 {
     const char* configfile = DEFAULT_CONFIG;
@@ -163,6 +165,10 @@ int main(int argc, char* argv[])
     int r;
     char* t;
     
+#ifndef HAVE___ARGV
+    __argv = argv;
+#endif
+
     /* Configuration defaults */
     memset(&g_clstate, 0, sizeof(g_clstate));
     g_clstate.directory = _PATH_TMP;
